@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2015, Phoronix Media
-	Copyright (C) 2008 - 2015, Michael Larabel
+	Copyright (C) 2008 - 2016, Phoronix Media
+	Copyright (C) 2008 - 2016, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -123,7 +123,7 @@ class info implements pts_option_interface
 					echo PHP_EOL . 'Test Installed: No' . PHP_EOL;
 				}
 
-				$dependencies = $o->get_dependencies();
+				$dependencies = $o->get_external_dependencies();
 				if(!empty($dependencies) && !empty($dependencies[0]))
 				{
 					echo PHP_EOL . 'Software Dependencies:' . PHP_EOL;
@@ -142,7 +142,7 @@ class info implements pts_option_interface
 				{
 					if($result_object->test_profile->get_display_format() == 'BAR_GRAPH')
 					{
-						array_push($test_titles, $result_object->test_profile->get_title());
+						$test_titles[] = $result_object->test_profile->get_title();
 					}
 				}
 
