@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2015, Phoronix Media
-	Copyright (C) 2008 - 2015, Michael Larabel
+	Copyright (C) 2008 - 2016, Phoronix Media
+	Copyright (C) 2008 - 2016, Michael Larabel
 	phodevi_system.php: The PTS Device Interface object for the system software
 
 	This program is free software; you can redistribute it and/or modify
@@ -66,6 +66,9 @@ class phodevi_system extends phodevi_device_interface
 			case 'opengl-driver':
 				$property = new phodevi_device_property('sw_opengl_driver', phodevi::std_caching);
 				break;
+			case 'vulkan-driver':
+				$property = new phodevi_device_property('sw_vulkan_driver', phodevi::std_caching);
+				break;
 			case 'opengl-vendor':
 				$property = new phodevi_device_property('sw_opengl_vendor', phodevi::smart_caching);
 				break;
@@ -912,7 +915,14 @@ class phodevi_system extends phodevi_device_interface
 		if(phodevi::is_windows())
 		{
 			//$kernel_arch = strpos($_SERVER['PROCESSOR_ARCHITECTURE'], 64) !== false || strpos($_SERVER['PROCESSOR_ARCHITEW6432'], 64 != false) ? 'x86_64' : 'i686';
-			$kernel_arch = $_SERVER['PROCESSOR_ARCHITEW6432'] == 'AMD64' ? 'x86_64' : 'i686';
+			if(isset($_SERVER['PROCESSOR_ARCHITEW6432']))
+			{
+				$kernel_arch = $_SERVER['PROCESSOR_ARCHITEW6432'] == 'AMD64' ? 'x86_64' : 'i686';
+			}
+			else
+			{
+				$kernel_arch = 'x86_64';
+			}
 		}
 		else
 		{
@@ -952,9 +962,14 @@ class phodevi_system extends phodevi_device_interface
 		{
 			$os_version = phodevi_linux_parser::read_lsb('Release');
 
-			if($os_version == null && is_readable('/etc/os-release'))
+			if($os_version == null)
 			{
-				$os_release = parse_ini_file('/etc/os-release');
+				if(is_readable('/etc/os-release'))
+					$os_release = parse_ini_file('/etc/os-release');
+				else if(is_readable('/usr/lib/os-release'))
+					$os_release = parse_ini_file('/usr/lib/os-release');
+				else
+					$os_release = null;
 
 				if(isset($os_release['VERSION_ID']) && !empty($os_release['VERSION_ID']))
 				{
@@ -1005,6 +1020,13 @@ class phodevi_system extends phodevi_device_interface
 					$vendor = $os_release['NAME'];
 				}
 			}
+
+			if(($x = stripos($vendor, ' for ')) !== false)
+			{
+				$vendor = substr($vendor, 0, $x);
+			}
+
+			$vendor = str_replace(array(' Software'), null, $vendor);
 		}
 		else if(phodevi::is_hurd())
 		{
@@ -1573,6 +1595,25 @@ class phodevi_system extends phodevi_device_interface
 
 		return $info;
 	}
+	public static function sw_vulkan_driver()
+	{
+		// Vulkan driver/version
+		$info = null;
+
+		// A less than ideal fallback for some detection now
+		foreach(pts_file_io::glob('/etc/vulkan/icd.d/*.json') as $icd_json)
+		{
+			$icd_json = json_decode(file_get_contents($icd_json), true);
+
+			if(isset($icd_json['ICD']['api_version']) && !empty($icd_json['ICD']['api_version']))
+			{
+				$info = trim($icd_json['ICD']['api_version']);
+				break;
+			}
+		}
+
+		return $info;
+	}
 	public static function sw_opengl_vendor()
 	{
 		// OpenGL version
