@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2015, Phoronix Media
-	Copyright (C) 2008 - 2015, Michael Larabel
+	Copyright (C) 2008 - 2016, Phoronix Media
+	Copyright (C) 2008 - 2016, Michael Larabel
 	pho_graph.php: The core graph object that is used by the different graphing objects.
 
 	This program is free software; you can redistribute it and/or modify
@@ -141,8 +141,14 @@ abstract class pts_graph_core
 		$this->results = array();
 		if($this->is_multi_way_comparison)
 		{
-			foreach($this->test_result->test_result_buffer->buffer_items as &$buffer_item)
+			foreach($this->test_result->test_result_buffer->buffer_items as $i => &$buffer_item)
 			{
+				if($buffer_item->get_result_value() === null)
+				{
+					unset($this->test_result->test_result_buffer->buffer_items[$i]);
+					continue;
+				}
+
 				$identifier = array_map('trim', explode(':', $buffer_item->get_result_identifier()));
 
 				if($this->i['multi_way_comparison_invert_default'])
@@ -172,7 +178,7 @@ abstract class pts_graph_core
 					$this->results[$date] = array();
 				}
 
-				array_push($this->results[$date], $buffer_item);
+				$this->results[$date][] = $buffer_item;
 				pts_arrays::unique_push($this->graph_identifiers, $system);
 			}
 
@@ -183,11 +189,17 @@ abstract class pts_graph_core
 		}
 		else if(isset($this->test_result->test_result_buffer))
 		{
-			$this->results = array($this->test_result->test_result_buffer->buffer_items);
-			foreach($this->test_result->test_result_buffer->buffer_items as &$buffer_item)
+			foreach($this->test_result->test_result_buffer->buffer_items as $i => &$buffer_item)
 			{
-				array_push($this->graph_identifiers, $buffer_item->get_result_identifier());
+				if($buffer_item->get_result_value() === null)
+				{
+					unset($this->test_result->test_result_buffer->buffer_items[$i]);
+					continue;
+				}
+
+				$this->graph_identifiers[] = $buffer_item->get_result_identifier();
 			}
+			$this->results = array($this->test_result->test_result_buffer->buffer_items);
 		}
 	}
 	public function override_i_value($key, $val)
@@ -269,13 +281,13 @@ abstract class pts_graph_core
 		{
 			if(!empty($sub_title))
 			{
-				array_push($this->graph_sub_titles, $sub_title);
+				$this->graph_sub_titles[] = $sub_title;
 			}
 		}
 	}
 	public function addTestNote($note, $hover_title = null, $section = null)
 	{
-		array_push($this->i['notes'], array('note' => $note, 'hover-title' => $hover_title, 'section' => $section));
+		$this->i['notes'][] = array('note' => $note, 'hover-title' => $hover_title, 'section' => $section);
 	}
 
 	//
@@ -311,7 +323,10 @@ abstract class pts_graph_core
 				$data_max = max($data_max);
 			}
 
-			$data_max = str_repeat(9, strlen($data_max));
+			if(!is_numeric($data_max))
+			{
+				$data_max = str_repeat(9, strlen($data_max));
+			}
 		}
 		if($data_max > $real_maximum)
 		{
@@ -366,6 +381,33 @@ abstract class pts_graph_core
 			$this->i['graph_left_end'] = $this->i['graph_width'] - $this->i['left_end_right'];
 		}
 	}
+	protected function identifier_to_branded_color($identifier, $fallback_color = null)
+	{
+		// See if the result identifier matches something to be color-coded better
+		$identifier = strtolower($identifier) . ' ';
+		if(strpos($identifier, 'geforce') !== false || strpos($identifier, 'nvidia') || strpos($identifier, 'quadro') !== false)
+		{
+			$paint_color = '#77b900';
+		}
+		else if(strpos($identifier, 'radeon') !== false || strpos($identifier, 'amd ') !== false || strpos($identifier, 'firepro ') !== false)
+		{
+			$paint_color = '#f1052d';
+		}
+		else if(strpos($identifier, 'intel ') !== false)
+		{
+			$paint_color = '#0b5997';
+		}
+		else if(strpos($identifier, 'bsd') !== false)
+		{
+			$paint_color = '#850000';
+		}
+		else
+		{
+			$paint_color = $fallback_color;
+		}
+
+		return $paint_color;
+	}
 
 	//
 	// Render Functions
@@ -464,7 +506,7 @@ abstract class pts_graph_core
 					$longest_string = pts_strings::find_longest_string($longest_string);
 
 					$rotated_text = round(self::text_string_width($longest_string, $this->i['identifier_size']) * 0.96);
-					$per_identifier_height = max((14 + (22 * count($this->results))), $rotated_text);
+					$per_identifier_height = max((14 + (14 * count($this->results))), $rotated_text);
 				}
 				else if(count($this->results) > 3)
 				{
@@ -781,7 +823,7 @@ abstract class pts_graph_core
 	}
 	protected function graph_key_height()
 	{
-		if(count($this->results) < 2 && $this->i['show_graph_key'] == false) // TODO likely should be OR
+		if((count($this->results) < 2 || $this->i['show_graph_key'] == false) && !$this->is_multi_way_comparison) // TODO likely should be OR
 		{
 			return 0;
 		}
@@ -886,7 +928,7 @@ abstract class pts_graph_core
 
 				if($note['section'] != null)
 				{
-					array_push($sections, $note['section']);
+					$sections[] = $note['section'];
 				}
 			}
 			$note_height += self::$c['size']['key'];
