@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2015, Phoronix Media
-	Copyright (C) 2008 - 2015, Michael Larabel
+	Copyright (C) 2008 - 2016, Phoronix Media
+	Copyright (C) 2008 - 2016, Michael Larabel
 	pts_LineGraph.php: The line graph object that extends pts_Graph.php.
 
 	This program is free software; you can redistribute it and/or modify
@@ -31,6 +31,15 @@ class pts_graph_lines extends pts_graph_core
 		{
 			foreach($result_object->test_result_buffer->buffer_items as &$buffer_item)
 			{
+				/*
+				$r = pts_strings::comma_explode($buffer_item->get_result_raw());
+				$c = count($r);
+				foreach($r as $val)
+				{
+					echo $val;
+				}
+				*/
+
 				$values = pts_strings::comma_explode($buffer_item->get_result_value());
 				$buffer_item->reset_result_value($values);
 				$buffer_item->reset_raw_value(pts_strings::comma_explode($buffer_item->get_result_raw()));
@@ -48,7 +57,8 @@ class pts_graph_lines extends pts_graph_core
 		$this->i['display_select_identifiers'] = false;
 		$this->i['hide_graph_identifiers'] = !isset($extra_attributes['force_tracking_line_graph']) || !$extra_attributes['force_tracking_line_graph'];
 
-		if($this->is_multi_way_comparison && isset($extra_attributes['force_tracking_line_graph']) && $extra_attributes['force_tracking_line_graph'] && is_array($this->results))
+		// XXX removed on 20 January from here: $this->is_multi_way_comparison &&
+		if(isset($extra_attributes['force_tracking_line_graph']) && $extra_attributes['force_tracking_line_graph'] && is_array($this->results))
 		{
 			// need to do compacting here
 			$this->test_result->test_result_buffer = new pts_test_result_buffer();
@@ -115,8 +125,17 @@ class pts_graph_lines extends pts_graph_core
 			}
 		}
 
-		$max_value *= 1.25; // leave room at top of graph
-		$this->i['graph_max_value'] = round($max_value, $max_value < 10 ? 1 : 0);
+		if($this->graph_y_title == 'Percent' && $max_value < 100 && $max_value > 80)
+		{
+			$this->i['graph_max_value'] = 120;
+			$this->i['mark_count'] = 6;
+		}
+		else
+		{
+			$max_value *= 1.25; // leave room at top of graph
+			$this->i['graph_max_value'] = round($max_value, $max_value < 10 ? 1 : 0);
+			$this->i['graph_max_value'] = round(ceil($this->i['graph_max_value'] / $this->i['mark_count']), (0 - strlen($this->i['graph_max_value']) + 2)) * $this->i['mark_count'];
+		}
 	}
 	protected function render_graph_identifiers()
 	{
@@ -235,7 +254,7 @@ class pts_graph_lines extends pts_graph_core
 				$precise_stat_array = array();
 				foreach($stat_array as $stat_value)
 				{
-					array_push($precise_stat_array, pts_math::set_precision($stat_value, $precision));
+					$precise_stat_array[] = pts_math::set_precision($stat_value, $precision);
 				}
 
 				$attributes['x'] = $x_stat_loc;
@@ -302,7 +321,7 @@ class pts_graph_lines extends pts_graph_core
 					$value_plot_top = $this->i['graph_top_end'] - 1;
 				}
 
-				array_push($poly_points, array($px_from_left, $value_plot_top, $data_string, $std_error));
+				$poly_points[] = array($px_from_left, $value_plot_top, $data_string, $std_error);
 
 				if(isset($this->d['regression_marker_threshold']) && $this->d['regression_marker_threshold'] > 0 && $i > 0 && abs(1 - ($value / $prev_value)) > $this->d['regression_marker_threshold'])
 				{
@@ -330,7 +349,7 @@ class pts_graph_lines extends pts_graph_core
 		$svg_poly = array();
 		foreach($poly_points as $x_y)
 		{
-			array_push($svg_poly, round($x_y[0]) . ',' . round($x_y[1]));
+			$svg_poly[] = round($x_y[0]) . ',' . round($x_y[1]);
 		}
 		$svg_poly = implode(' ', $svg_poly);
 		$this->svg_dom->add_element('polyline', array('points' => $svg_poly, 'fill' => 'none', 'stroke-width' => 2), $g);
