@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2015, Phoronix Media
-	Copyright (C) 2008 - 2015, Michael Larabel
+	Copyright (C) 2008 - 2016, Phoronix Media
+	Copyright (C) 2008 - 2016, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -312,7 +312,7 @@ class pts_network
 		}
 		else if(!PTS_IS_WEB_CLIENT)
 		{
-			$server_response = pts_network::http_get_contents('http://www.phoronix-test-suite.com/PTS', false, false);
+			$server_response = pts_network::http_get_contents('http://openbenchmarking.org/PTS', false, false);
 
 			if($server_response != 'PTS')
 			{
@@ -331,7 +331,7 @@ class pts_network
 						foreach(array(20, 40) as $time_to_wait)
 						{
 							sleep($time_to_wait);
-							$server_response = pts_network::http_get_contents('http://www.phoronix-test-suite.com/PTS', false, false);
+							$server_response = pts_network::http_get_contents('http://openbenchmarking.org/PTS', false, false);
 							if($server_response != 'PTS' && gethostbyname('google.com') == 'google.com')
 							{
 								trigger_error('No Internet Connectivity After Wait', E_USER_WARNING);
@@ -527,7 +527,7 @@ class pts_network
 
 						if($find_multiple)
 						{
-							array_push($hosts, array($server_ip, $server_port));
+							$hosts[] = array($server_ip, $server_port);
 						}
 						else
 						{
